@@ -27,15 +27,16 @@ def distinct(l):
         return []
     return list(set(l))
 
-def get_source_files(sources,extension='.sass'):
+def get_source_files(sources, extensions='.sass,.scss'):
     source_files = []
     for s in sources:
         p = os.path.abspath(s)
         if os.path.isfile(p):
             source_files.append(p)
         elif os.path.isdir(p):
-            for _f in glob.iglob(os.path.join(p,'*%s' % extension)):
-                source_files.append(os.path.abspath(_f))
+            for extension in extensions.split(','):
+                for _f in glob.iglob(os.path.join(p,'*%s' % extension)):
+                    source_files.append(os.path.abspath(_f))
     return sorted(distinct(source_files))
 
 def get_source_dirs(sources):
